import requests
import pandas as pd
import urllib
from ensure import ensure_annotations

APP_NAME = "com.xiaomi.hm.health"
APP_PLATFORM = "web"
BASE_URL = "https://api-mifit.huami.com"
endpoint = "/v1/sport/run/history.json"


@ensure_annotations
def get_data(args):

    access_token = input("Please input your access token: ")

    response = requests.get(
        urllib.parse.urljoin(BASE_URL, endpoint),
        headers={
            "apptoken": access_token,
            "appPlatform": APP_PLATFORM,
            "appname": APP_NAME,
        },
        params={},
    )

    data = pd.DataFrame(response.json()["data"]["summary"])
    print(data.head())
    data.to_csv("workouts.csv", index=False, header=True)



import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

__version__ = "0.0.6"

REPO_NAME = "mi-band-data-extract"
AUTHOR_USER_NAME =  "SurajpratapsinghSayar"
SRC_REPO = "mi_band_data_extract"
AUTHOR_EMAIL = "sunnysayar@outlook.com"

setuptools.setup(
    name=SRC_REPO,
    version=__version__,
    author=AUTHOR_USER_NAME,
    author_email=AUTHOR_EMAIL,
    description="Package to extract data from Mi Band data files.",
    long_description=long_description,
    long_description_content = "text/md",
    url=f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}",
    project_urls={
        "Bug Tracker": f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues"
    },
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src")
)



import os
import sys
import logging

logging_str = "[%(asctime)s: %(levelname)s: %(module)s]: %(message)s"
log_dir = "./logs"
log_filepath = os.path.join(log_dir, "running_logs.log")
os.makedirs(log_dir, exist_ok=True)

logging.basicConfig(
    level=logging.INFO,
    format=logging_str,
    handlers=[logging.FileHandler(log_filepath), logging.StreamHandler(sys.stdout)],
)

logger = logging.getLogger("mi-band-data-extract")